/* Source Installer, Copyright (c) 2005,2006,2007 Claudio Fontana

 package_list.h - the widget holding all the package names

 This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.

 This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
     along with this program (look for the file called COPYING);
     if not, write to the Free Software Foundation, Inc.,
         51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

     You can contact the author (Claudio Fontana) by sending a mail
     to claudio@gnu.org
*/

#ifndef PACKAGE_LIST_H
#define PACKAGE_LIST_H

enum {
    W_PACKAGE_LIST_SCR,
    W_PACKAGE_LIST,

    W_PACKAGE_LIST_N
};

extern GtkWidget *w_package_list[W_PACKAGE_LIST_N];
extern struct srcinst_string_list package_list;

void package_list_create(void);
void package_list_fill(void);
void package_list_update(void);


void package_list_row_activated(GtkTreeView * tree, GtkTreePath * path,
				GtkTreeViewColumn * column,
				gpointer user_data);
void package_list_cursor_changed(GtkTreeView * tree, gpointer user_data);
gboolean package_list_popup_menu(GtkWidget * widget, gpointer user_data);
gboolean package_list_button_press_event(GtkWidget * widget,
					 GdkEventButton * event,
					 gpointer user_data);


#endif				/* PACKAGE_LIST_H */
